srim-python
===========

A package for automating SRIM input and output analysis.

.. image:: https://gitlab.aves.io/costrouc/pysrim/raw/master/examples/images/length-heatmap-log.png

Features
========

- *Automates* running SRIM

- *Post processes* SRIM runs

See `jupyter notebook <https://gitlab.aves.io/costrouc/pysrim/blob/master/examples/notebooks/Analysis.ipynb>`_ for full demonstration of features.

An example of creating some publication graphics with pysrim can also be found in that `directory <https://gitlab.aves.io/costrouc/pysrim/blob/master/examples/notebooks/SiC.ipynb>`_


Installation
===========

SRIM can run perfectly on linux with `wine <https://www.winehq.org/>`_

Run the `install script <https://gitlab.aves.io/costrouc/pysrim/raw/master/install.sh>`_ with bash.

Click extract and then done.
